@@ -11,9 +11,8 @@ const Signals = imports.signals;
 
 import NetworksManager from './networksManager.js';
 
-Gio._promisify(Tp.AccountManager.prototype, 'prepare_async', 'prepare_finish');
-Gio._promisify(Tp.Account.prototype,
-    'request_presence_async', 'request_presence_finish');
+Gio._promisify(Tp.AccountManager.prototype, 'prepare_async');
+Gio._promisify(Tp.Account.prototype, 'request_presence_async');
 
 export default class AccountsMonitor {
     static getDefault() {
@@ -34,7 +33,7 @@ export default class AccountsMonitor {
                 this._onPrepareShutdown.bind(this));
         }
 
-        let factory = new ClientFactory();
+        const factory = new ClientFactory();
         factory.add_channel_features([Tp.Channel.get_feature_quark_group()]);
         factory.add_channel_features([Tp.Channel.get_feature_quark_contacts()]);
         factory.add_contact_features([Tp.ContactFeature.ALIAS]);
@@ -63,7 +62,7 @@ export default class AccountsMonitor {
     }
 
     prepare(callback) {
-        let quark = Tp.AccountManager.get_feature_quark_core();
+        const quark = Tp.AccountManager.get_feature_quark_core();
         if (this._accountManager.is_prepared(quark))
             callback();
         else
@@ -73,7 +72,7 @@ export default class AccountsMonitor {
     _onPrepared(am, res) {
         try {
             am.prepare_finish(res);
-        } catch (e) {
+        } catch {
             this._app.release();
             return; // no point in carrying on
         }
@@ -140,7 +139,7 @@ export default class AccountsMonitor {
         account._visibleNotifyId =
             account.connect('notify::visible', () => {
                 this._updateAccountReachable(account);
-                let signal = account.visible
+                const signal = account.visible
                     ? 'account-shown' : 'account-hidden';
                 this.emit(signal, account);
                 this.emit('accounts-changed');
@@ -171,7 +170,7 @@ export default class AccountsMonitor {
     _accountEnabledChanged(am, account) {
         if (!this._accounts.has(account.object_path))
             return;
-        let signal = account.enabled ? 'account-enabled' : 'account-disabled';
+        const signal = account.enabled ? 'account-enabled' : 'account-disabled';
         this.emit(signal, account);
         this.emit('accounts-changed');
     }
@@ -180,7 +179,7 @@ export default class AccountsMonitor {
         if (!this._networkMonitor.state_valid)
             return;
 
-        let servers = account.getServers().map(s => {
+        const servers = account.getServers().map(s => {
             return new Gio.NetworkAddress({
                 hostname: s.address,
                 port: s.port,
@@ -188,15 +187,15 @@ export default class AccountsMonitor {
         });
 
         try {
-            let reachable = await this._canReachAny(servers);
+            const reachable = await this._canReachAny(servers);
             account._setReachable(reachable);
-        } catch (e) {
+        } catch {
             account._setReachable(false);
         }
     }
 
     _canReachAny(servers) {
-        let reverse = promise => {
+        const reverse = promise => {
             return new Promise((resolve, reject) => {
                 return Promise.resolve(promise).then(reject, resolve);
             });
@@ -234,19 +233,19 @@ const PolariAccount = GObject.registerClass(
 class PolariAccount extends Tp.Account {
     static [GObject.properties] = {
         predefined: GObject.ParamSpec.boolean(
-            'predefined', 'predefined', 'predefined',
+            'predefined', null, null,
             GObject.ParamFlags.READABLE,
             false),
         reachable: GObject.ParamSpec.boolean(
-            'reachable', 'reachable', 'reachable',
+            'reachable', null, null,
             GObject.ParamFlags.READABLE,
             false),
         visible: GObject.ParamSpec.boolean(
-            'visible', 'visible', 'visible',
+            'visible', null, null,
             GObject.ParamFlags.READWRITE,
             true),
         settings: GObject.ParamSpec.object(
-            'settings', 'settings', 'settings',
+            'settings', null, null,
             GObject.ParamFlags.READABLE,
             Gio.Settings.$gtype),
     };
@@ -293,13 +292,13 @@ class PolariAccount extends Tp.Account {
     }
 
     getConnectionParams() {
-        let params = this.dup_parameters_vardict().deep_unpack();
-        for (let p in params)
+        const params = this.dup_parameters_vardict().deep_unpack();
+        for (const p in params)
             params[p] = params[p].deep_unpack();
 
         params['use-ssl'] = !!params['use-ssl'];
 
-        let defaultPort = params['use-ssl'] ? 6697 : 6667;
+        const defaultPort = params['use-ssl'] ? 6697 : 6667;
         params['port'] = params['port'] || defaultPort;
 
         return params;
@@ -309,7 +308,7 @@ class PolariAccount extends Tp.Account {
         if (this.predefined)
             return this._networksManager.getNetworkServers(this.service);
 
-        let params = this.getConnectionParams();
+        const params = this.getConnectionParams();
         return [{
             address: params.server,
             port: params.port,
