@@ -27,17 +27,12 @@ import TelepathyClient from './telepathyClient.js';
 import UserStatusMonitor from './userTracker.js';
 import * as Utils from './utils.js';
 
-Gio._promisify(Tp.AccountRequest.prototype,
-    'create_account_async', 'create_account_finish');
-Gio._promisify(Tp.Account.prototype, 'remove_async', 'remove_finish');
-Gio._promisify(Tp.Account.prototype,
-    'request_presence_async', 'request_presence_finish');
-Gio._promisify(Tp.Account.prototype,
-    'set_enabled_async', 'set_enabled_finish');
-Gio._promisify(Tp.Account.prototype,
-    'set_nickname_async', 'set_nickname_finish');
-Gio._promisify(Tp.Account.prototype,
-    'update_parameters_vardict_async', 'update_parameters_vardict_finish');
+Gio._promisify(Tp.AccountRequest.prototype, 'create_account_async');
+Gio._promisify(Tp.Account.prototype, 'remove_async');
+Gio._promisify(Tp.Account.prototype, 'request_presence_async');
+Gio._promisify(Tp.Account.prototype, 'set_enabled_async');
+Gio._promisify(Tp.Account.prototype, 'set_nickname_async');
+Gio._promisify(Tp.Account.prototype, 'update_parameters_vardict_async');
 
 const MAX_RETRIES = 3;
 
@@ -103,7 +98,7 @@ class Application extends Adw.Application {
 
             try {
                 this.register(null);
-            } catch (e) {
+            } catch {
                 return 1;
             }
 
@@ -136,14 +131,15 @@ class Application extends Adw.Application {
     }
 
     _checkService(conn, name, opath, iface) {
-        let flags = Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES |
-                    Gio.DBusProxyFlags.DO_NOT_CONNECT_SIGNALS;
+        const flags =
+            Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES |
+            Gio.DBusProxyFlags.DO_NOT_CONNECT_SIGNALS;
         let proxy = null;
 
         try {
             proxy = Gio.DBusProxy.new_sync(
                 conn, flags, null, name, opath, iface, null);
-        } catch (e) {}
+        } catch {}
 
         return proxy !== null && proxy.get_name_owner() !== null;
     }
@@ -157,7 +153,7 @@ class Application extends Adw.Application {
         console.info(`Failed to activate service ${
             name}, starting manually`);
 
-        let proc = new Gio.Subprocess({argv: [command]});
+        const proc = new Gio.Subprocess({argv: [command]});
 
         try {
             proc.init(null);
@@ -180,9 +176,9 @@ class Application extends Adw.Application {
             this.hold();
             this._importingLogs = true;
 
-            let importer = new Logger.LogImporter();
+            const importer = new Logger.LogImporter();
 
-            let numFiles = await importer.init();
+            const numFiles = await importer.init();
             let n = 0;
             this.activeWindow?.showImportProgress(n, numFiles);
 
@@ -203,12 +199,12 @@ class Application extends Adw.Application {
     }
 
     _maybeMakeNonUnique() {
-        let bus = Gio.BusType.SESSION;
-        let name = this.application_id;
-        let flags = Gio.BusNameWatcherFlags.NONE;
+        const bus = Gio.BusType.SESSION;
+        const name = this.application_id;
+        const flags = Gio.BusNameWatcherFlags.NONE;
 
         let handled = false;
-        let id = Gio.bus_watch_name(bus, name, flags, () => {
+        const id = Gio.bus_watch_name(bus, name, flags, () => {
             console.info(
                 'Running as test instance alongside primary instance');
             this.set_flags(this.flags | Gio.ApplicationFlags.NON_UNIQUE);
@@ -219,7 +215,7 @@ class Application extends Adw.Application {
         });
 
         // Evil-ish ...
-        let main = GLib.MainContext.default();
+        const main = GLib.MainContext.default();
         while (!handled)
             main.iteration(true);
         Gio.bus_unwatch_name(id);
@@ -244,7 +240,7 @@ class Application extends Adw.Application {
     }
 
     vfunc_dbus_unregister(_conn, _path) {
-        for (let proc of this._demons)
+        for (const proc of this._demons)
             proc.force_exit();
         this._demons = [];
     }
@@ -335,6 +331,9 @@ class Application extends Adw.Application {
             name: 'quit',
             activate: this._onQuit.bind(this),
             accels: ['<Primary>q'],
+        }, {
+            name: 'search',
+            accels: ['<Primary>s'],
         }, {
             name: 'next-room',
             accels: ['<Primary>Page_Down', '<Alt>Down'],
@@ -391,7 +390,7 @@ class Application extends Adw.Application {
         // The portal implementation fetches the initial state asynchronously,
         // so track when the it becomes valid to not base decisions on an
         // incorrect offline state
-        let networkMonitor = Gio.NetworkMonitor.get_default();
+        const networkMonitor = Gio.NetworkMonitor.get_default();
         networkMonitor.state_valid =
             !Utils.isFlatpakSandbox() &&
             GLib.getenv('GTK_USE_PORTAL') !== '1';
@@ -400,7 +399,7 @@ class Application extends Adw.Application {
             if (!networkMonitor.network_metered)
                 this._serverRoomManager = ServerRoomManager.getDefault();
         } else {
-            let id = networkMonitor.connect('network-changed', () => {
+            const id = networkMonitor.connect('network-changed', () => {
                 networkMonitor.disconnect(id);
                 networkMonitor.state_valid = true;
 
@@ -413,7 +412,7 @@ class Application extends Adw.Application {
             this._onAccountStatusChanged.bind(this));
         this._accountsMonitor.connect('account-added', (am, account) => {
             // Reset nickname at startup
-            let accountName = this._getTrimmedAccountName(account);
+            const accountName = this._getTrimmedAccountName(account);
             account.set_nickname_async(accountName);
         });
         this._accountsMonitor.connect('account-removed', (am, account) => {
@@ -434,7 +433,7 @@ class Application extends Adw.Application {
             if (this._needsInitialSetup()) {
                 new InitialSetupWindow({application: this});
             } else {
-                let window = new MainWindow({application: this});
+                const window = new MainWindow({application: this});
                 window.connect('notify::active-room',
                     () => this.emit('room-focus-changed'));
                 window.connect('notify::is-active',
@@ -451,7 +450,7 @@ class Application extends Adw.Application {
         if (!(window instanceof MainWindow))
             return;
 
-        let action = this.lookup_action('leave-current-room');
+        const action = this.lookup_action('leave-current-room');
         action.enabled = window.active_room !== null;
 
         this._toplevelSignals = [
@@ -478,7 +477,7 @@ class Application extends Adw.Application {
     vfunc_open(files) {
         this.activate();
 
-        let uris = files.map(f => f.get_uri());
+        const uris = files.map(f => f.get_uri());
 
         this._accountsMonitor.prepare(() => {
             this._openURIs(uris);
@@ -486,24 +485,24 @@ class Application extends Adw.Application {
     }
 
     _openURIs(uris) {
-        let map = {};
+        const map = {};
 
         this._accountsMonitor.visibleAccounts.forEach(a => {
-            let params = a.dup_parameters_vardict().deep_unpack();
+            const params = a.dup_parameters_vardict().deep_unpack();
             map[a.get_object_path()] = {
                 server: params.server.deep_unpack(),
                 service: a.service,
             };
         });
 
-        let joinAction = this.lookup_action('join-room');
+        const joinAction = this.lookup_action('join-room');
         uris.forEach(async uri => {
-            let [success, server, port, room] = this._parseURI(uri);
+            const [success, server, port, room] = this._parseURI(uri);
             if (!success)
                 return;
 
-            let matchedId = this._networksManager.findByServer(server);
-            let matches = Object.keys(map).filter(a => {
+            const matchedId = this._networksManager.findByServer(server);
+            const matches = Object.keys(map).filter(a => {
                 return GLib.ascii_strcasecmp(map[a].server, server) === 0 ||
                        map[a].service === matchedId;
             });
@@ -527,7 +526,7 @@ class Application extends Adw.Application {
         try {
             [,, server, port, room] = uri.match(IRC_SCHEMA_REGEX);
             success = true;
-        } catch (e) {
+        } catch {
             const toast = new Adw.Toast({
                 title: _('Failed to open link'),
             });
@@ -553,7 +552,7 @@ class Application extends Adw.Application {
             name = server;
         }
 
-        let req = new Tp.AccountRequest({
+        const req = new Tp.AccountRequest({
             account_manager: Tp.AccountManager.dup(),
             connection_manager: 'idle',
             protocol: 'irc',
@@ -564,7 +563,7 @@ class Application extends Adw.Application {
         if (id)
             req.set_service(id);
 
-        for (let prop in params)
+        for (const prop in params)
             req.set_parameter(prop, params[prop]);
 
         const account = await req.create_account_async();
@@ -584,7 +583,7 @@ class Application extends Adw.Application {
         if (!Utils.needsOnetimeAction('initial-setup'))
             return;
 
-        let savedRooms = this._settings.get_value('saved-channel-list');
+        const savedRooms = this._settings.get_value('saved-channel-list');
         return savedRooms.n_children() === 0;
     }
 
@@ -597,8 +596,8 @@ class Application extends Adw.Application {
     }
 
     _updateUserListAction() {
-        let room = this.active_window.active_room;
-        let action = this.lookup_action('user-list');
+        const room = this.active_window.active_room;
+        const action = this.lookup_action('user-list');
         action.enabled = room && room.type === Tp.HandleType.ROOM && room.channel;
     }
 
@@ -612,12 +611,12 @@ class Application extends Adw.Application {
     }
 
     _onJoinRoom(action, parameter) {
-        let [accountPath_, channelName_, present] = parameter.deep_unpack();
+        const [accountPath_, channelName_, present] = parameter.deep_unpack();
         this._maybePresent(present);
     }
 
     _onMessageUser(action, parameter) {
-        let [accountPath_, contactName_, msg_, present] = parameter.deep_unpack();
+        const [accountPath_, contactName_, msg_, present] = parameter.deep_unpack();
         this._maybePresent(present);
     }
 
@@ -625,16 +624,16 @@ class Application extends Adw.Application {
         if (this._nickTrackData.has(account))
             return;
 
-        let nominalNick = this._getTrimmedAccountName(account);
-        let baseNick = Polari.util_get_basenick(nominalNick);
+        const nominalNick = this._getTrimmedAccountName(account);
+        const baseNick = Polari.util_get_basenick(nominalNick);
 
-        let tracker = this._userStatusMonitor.getUserTrackerForAccount(account);
-        let contactsChangedId = tracker.connect(`contacts-changed::${baseNick}`,
+        const tracker = this._userStatusMonitor.getUserTrackerForAccount(account);
+        const contactsChangedId = tracker.connect(`contacts-changed::${baseNick}`,
             (t, nick) => {
                 if (nick !== nominalNick)
                     return;
 
-                let contact = tracker.lookupContact(nick);
+                const contact = tracker.lookupContact(nick);
                 if (contact && contact.alias === nick)
                     return;
 
@@ -645,7 +644,7 @@ class Application extends Adw.Application {
     }
 
     _untrackNominalNick(account) {
-        let data = this._nickTrackData.get(account);
+        const data = this._nickTrackData.get(account);
         if (!data)
             return;
 
@@ -658,8 +657,8 @@ class Application extends Adw.Application {
         if (data)
             return data;
 
-        let params = account.getConnectionParams();
-        let {server, account: accountName, port} = params;
+        const params = account.getConnectionParams();
+        const {server, account: accountName, port} = params;
         console.info(`Failed to connect to ${server} with username ${
             accountName}`);
 
@@ -677,14 +676,14 @@ class Application extends Adw.Application {
     }
 
     _getTrimmedAccountName(account) {
-        let params = account.getConnectionParams();
+        const params = account.getConnectionParams();
         return params.account.replace(/_+$/, '');
     }
 
     _restoreAccountName(account) {
-        let accountName = this._getTrimmedAccountName(account);
-        let params = {account: new GLib.Variant('s', accountName)};
-        let asv = new GLib.Variant('a{sv}', params);
+        const accountName = this._getTrimmedAccountName(account);
+        const params = {account: new GLib.Variant('s', accountName)};
+        const asv = new GLib.Variant('a{sv}', params);
         account.update_parameters_vardict_async(asv, []);
     }
 
@@ -697,31 +696,31 @@ class Application extends Adw.Application {
     }
 
     _retryNickRequest(account) {
-        let retryData = this._ensureRetryData(account);
+        const retryData = this._ensureRetryData(account);
 
         if (retryData.retry++ >= MAX_RETRIES)
             return false;
 
         this._trackNominalNick(account);
 
-        let oldParams = account.dup_parameters_vardict().deep_unpack();
-        let nick = oldParams['account'].deep_unpack();
+        const oldParams = account.dup_parameters_vardict().deep_unpack();
+        const nick = oldParams['account'].deep_unpack();
 
         console.info(`Retrying with nickname ${nick}_`);
-        let params = {account: new GLib.Variant('s', `${nick}_`)};
+        const params = {account: new GLib.Variant('s', `${nick}_`)};
         this._retryWithParams(account, new GLib.Variant('a{sv}', params));
         return true;
     }
 
     _retryServerRequest(account) {
-        let retryData = this._ensureRetryData(account);
+        const retryData = this._ensureRetryData(account);
 
-        let server = retryData.alternateServers.shift();
+        const server = retryData.alternateServers.shift();
         if (!server)
             return false;
 
         console.info(`Retrying with ${server.address}:${server.port}`);
-        let params = {
+        const params = {
             server: new GLib.Variant('s', server.address),
             port: new GLib.Variant('u', server.port),
             'use-ssl': new GLib.Variant('b', server.ssl),
@@ -731,13 +730,13 @@ class Application extends Adw.Application {
     }
 
     _onAccountStatusChanged(mon, account) {
-        let status = account.connection_status;
+        const status = account.connection_status;
 
         if (status === Tp.ConnectionStatus.CONNECTING)
             return;
 
         if (status === Tp.ConnectionStatus.DISCONNECTED) {
-            let reason = account.connection_status_reason;
+            const reason = account.connection_status_reason;
 
             if (reason === Tp.ConnectionStatusReason.NAME_IN_USE) {
                 if (this._retryNickRequest(account))
@@ -751,14 +750,14 @@ class Application extends Adw.Application {
             }
 
             if (reason !== Tp.ConnectionStatusReason.REQUESTED) {
-                let strReason = Object.keys(Tp.ConnectionStatusReason)[reason];
-                let name = account.display_name;
+                const strReason = Object.keys(Tp.ConnectionStatusReason)[reason];
+                const name = account.display_name;
                 console.info(`Account ${name} disconnected with reason ${
                     strReason}`);
 
                 // Connection failed, keep tp from retrying over and over
-                let presence = Tp.ConnectionPresenceType.OFFLINE;
-                let msg = account.requested_status_message;
+                const presence = Tp.ConnectionPresenceType.OFFLINE;
+                const msg = account.requested_status_message;
                 account.request_presence_async(presence, 'offline', msg);
             }
         }
@@ -767,29 +766,29 @@ class Application extends Adw.Application {
     }
 
     _onLeaveCurrentRoom() {
-        let room = this.active_window.active_room;
+        const room = this.active_window.active_room;
         if (!room)
             return;
-        let action = this.lookup_action('leave-room');
+        const action = this.lookup_action('leave-room');
         action.activate(GLib.Variant.new('(ss)', [room.id, '']));
     }
 
     _onConnectAccount(action, parameter) {
-        let accountPath = parameter.deep_unpack();
-        let account = this._accountsMonitor.lookupAccount(accountPath);
+        const accountPath = parameter.deep_unpack();
+        const account = this._accountsMonitor.lookupAccount(accountPath);
         if (account)
             this._restoreAccountName(account);
         this._retryData.delete(accountPath);
     }
 
     _onToggleAction(action) {
-        let state = action.get_state();
+        const state = action.get_state();
         action.change_state(GLib.Variant.new('b', !state.get_boolean()));
     }
 
     async _onRemoveConnection(action, parameter) {
-        let accountPath = parameter.deep_unpack();
-        let account = this._accountsMonitor.lookupAccount(accountPath);
+        const accountPath = parameter.deep_unpack();
+        const account = this._accountsMonitor.lookupAccount(accountPath);
 
         await account.set_enabled_async(false);
         this._removedAccounts.add(account);
@@ -823,8 +822,8 @@ class Application extends Adw.Application {
     }
 
     _onEditConnection(action, parameter) {
-        let accountPath = parameter.deep_unpack();
-        let account = this._accountsMonitor.lookupAccount(accountPath);
+        const accountPath = parameter.deep_unpack();
+        const account = this._accountsMonitor.lookupAccount(accountPath);
         const dialog = new Connections.ConnectionProperties(account);
         dialog.present(this.activeWindow);
     }
@@ -833,7 +832,7 @@ class Application extends Adw.Application {
         if (this._telepathyClient)
             return;
 
-        let params = {
+        const params = {
             name: 'Polari',
             account_manager: this._accountsMonitor.accountManager,
             uniquify_name: this.isTestInstance,
