@@ -19,8 +19,7 @@ import TabCompletion from './tabCompletion.js';
 const MAX_NICK_UPDATE_TIME = 5; /* s */
 const MAX_LINES = 5;
 
-Gio._promisify(Gio._LocalFilePrototype,
-    'query_info_async', 'query_info_finish');
+Gio._promisify(Gio._LocalFilePrototype, 'query_info_async');
 
 export const ChatEntry = GObject.registerClass(
 class ChatEntry extends Gtk.Entry {
@@ -41,8 +40,8 @@ class ChatEntry extends Gtk.Entry {
         const delegate = this.get_delegate();
         this.addTargets(delegate);
 
-        let app = Gio.Application.get_default();
-        let action = app.lookup_action('show-emoji-picker');
+        const app = Gio.Application.get_default();
+        const action = app.lookup_action('show-emoji-picker');
         action.connect('activate', () => {
             if (this.is_sensitive() && this.get_mapped())
                 delegate.emit('insert-emoji');
@@ -52,7 +51,6 @@ class ChatEntry extends Gtk.Entry {
         delegate.connect('paste-clipboard', this._onPasteClipboard.bind(this));
     }
 
-    // eslint-disable-next-line camelcase
     get can_drop() {
         return true;
     }
@@ -109,7 +107,7 @@ class NickPopover extends Gtk.Popover {
 
     static [GObject.properties] = {
         nick: GObject.ParamSpec.string(
-            'nick', 'nick', 'nick',
+            'nick', null, null,
             GObject.ParamFlags.READWRITE,
             ''),
     };
@@ -165,11 +163,11 @@ class EntryArea extends Gtk.Stack {
 
     static [GObject.properties] = {
         'max-nick-chars': GObject.ParamSpec.uint(
-            'max-nick-chars', 'max-nick-chars', 'max-nick-chars',
+            'max-nick-chars', null, null,
             GObject.ParamFlags.WRITABLE,
             0, GLib.MAXUINT32, 0),
         'confirmation-visible': GObject.ParamSpec.boolean(
-            'confirmation-visible', 'confirmation-visible', 'confirmation-visible',
+            'confirmation-visible', null, null,
             GObject.ParamFlags.READABLE,
             false),
     };
@@ -297,13 +295,11 @@ class EntryArea extends Gtk.Stack {
         this._chatEntry.connect('unmap', this._updateCompletions.bind(this));
     }
 
-    // eslint-disable-next-line camelcase
     set max_nick_chars(maxChars) {
         this._maxNickChars = maxChars;
         this._updateNick();
     }
 
-    // eslint-disable-next-line camelcase
     get confirmation_visible() {
         return this.visible_child_name === 'paste-confirmation';
     }
@@ -323,7 +319,7 @@ class EntryArea extends Gtk.Stack {
             this._room &&
             this._room.channel &&
             this._room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP)) {
-            let members = this._room.channel.group_dup_members_contacts();
+            const members = this._room.channel.group_dup_members_contacts();
             nicks = members.map(member => member.alias);
         }
         this._completion.setCompletions(nicks);
@@ -347,7 +343,7 @@ class EntryArea extends Gtk.Stack {
         if (state !== 0 && state !== Gdk.ModifierType.SHIFT_MASK)
             return Gdk.EVENT_PROPAGATE;
 
-        let activationKeys = [
+        const activationKeys = [
             Gdk.KEY_Tab,
             Gdk.KEY_Return,
             Gdk.KEY_ISO_Enter,
@@ -405,11 +401,11 @@ class EntryArea extends Gtk.Stack {
                 Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
                 Gio.FileQueryInfoFlags.NONE,
                 GLib.PRIORITY_DEFAULT, null);
-        } catch (e) {
+        } catch {
             return;
         }
 
-        let name = fileInfo.get_display_name();
+        const name = fileInfo.get_display_name();
         /* Translators: %s is a filename */
         this._confirmLabel.label = vprintf(_('Upload “%s” to public paste service?'), name);
         /* Translators: %s is a filename */
@@ -419,7 +415,7 @@ class EntryArea extends Gtk.Stack {
 
     async _onPasteClicked() {
         let title;
-        let nick = this._room.channel.connection.self_contact.alias;
+        const nick = this._room.channel.connection.self_contact.alias;
         if (this._room.type === Tp.HandleType.ROOM)
             /* translators: %s is a nick, #%s a channel */
             title = vprintf(_('%s in #%s'), nick, this._room.display_name);
@@ -428,9 +424,9 @@ class EntryArea extends Gtk.Stack {
         this._confirmLabel.hide();
 
         this._confirmLabel.hide();
-        this._uploadSpinner.start();
+        this._uploadSpinner.show();
 
-        let app = Gio.Application.get_default();
+        const app = Gio.Application.get_default();
         try {
             const url =
                 await app.pasteManager.pasteContent(this._pasteContent, title);
@@ -443,7 +439,7 @@ class EntryArea extends Gtk.Stack {
             console.warn(`Failed to paste content of type ${type}`);
             console.debug(e);
         } finally {
-            this._uploadSpinner.stop();
+            this._uploadSpinner.hide();
         }
     }
 
@@ -481,7 +477,7 @@ class EntryArea extends Gtk.Stack {
         if (!this.get_mapped())
             return;
 
-        let app = Gio.Application.get_default();
+        const app = Gio.Application.get_default();
         app.setAccountNick(this._room.account, nick);
 
         // TpAccount:nickname is a local property which doesn't
@@ -499,7 +495,7 @@ class EntryArea extends Gtk.Stack {
     }
 
     _updateNick() {
-        let {channel} = this._room || {};
+        const {channel} = this._room || {};
         let nick = '';
         if (channel)
             nick = channel.connection.self_contact.alias;
