@@ -5,9 +5,9 @@
 import GLib from 'gi://GLib';
 
 import * as Config from './config.js';
-import Polari from 'gi://Polari';
 import {ngettext} from 'gettext';
 import {programInvocationName, programArgs} from 'system';
+import * as Utils from './utils.js';
 
 imports.package.init({
     name: Config.PACKAGE_NAME,
@@ -19,7 +19,6 @@ imports.package.init({
 pkg.initGettext();
 globalThis.ngettext = ngettext;
 
-// eslint-disable-next-line no-restricted-properties
 globalThis.vprintf = (fmt, ...args) => imports.format.vprintf(fmt, args);
 
 pkg.require({
@@ -32,13 +31,13 @@ pkg.require({
     'TelepathyGLib': '0.12',
     'Tracker': '3.0',
 });
-pkg.requireSymbol('Adw', '1', 'ToolbarView');
+pkg.requireSymbol('Adw', '1', 'ShortcutsDialog');
 pkg.checkSymbol('Soup', '3.0');
 
 import Application from './application.js';
 
-let application = new Application();
+const application = new Application();
 if (GLib.getenv('POLARI_PERSIST'))
     application.hold();
 application.run([programInvocationName, ...programArgs]);
-Polari.util_close_tracker_connection();
+await Utils.getSparqlStore().close();
