@@ -16,6 +16,7 @@ import JoinDialog from './joinDialog.js';
 import RoomList_ from './roomList.js'; // used in template
 import RoomManager from './roomManager.js';
 import RoomStack_ from './roomStack.js'; // used in template
+import SearchView_ from './searchView.js'; // used in template
 import * as UserList_ from './userList.js'; // used in template
 import * as Utils from './utils.js';
 
@@ -30,25 +31,31 @@ class MainWindow extends Adw.ApplicationWindow {
         'roomListRevealer',
         'offlineBanner',
         'overlay',
+        'roomList',
         'roomStack',
         'importProgress',
+        'searchButton',
+        'searchEntry',
+        'searchTitle',
+        'searchView',
+        'viewStack',
     ];
 
     static [GObject.properties] = {
         subtitle: GObject.ParamSpec.string(
-            'subtitle', 'subtitle', 'subtitle',
+            'subtitle', null, null,
             GObject.ParamFlags.READABLE,
             ''),
         'subtitle-visible': GObject.ParamSpec.boolean(
-            'subtitle-visible', 'subtitle-visible', 'subtitle-visible',
+            'subtitle-visible', null, null,
             GObject.ParamFlags.READABLE,
             false),
         'active-room': GObject.ParamSpec.object(
-            'active-room', 'active-room', 'active-room',
+            'active-room', null, null,
             GObject.ParamFlags.READWRITE,
             Polari.Room.$gtype),
         'view-height': GObject.ParamSpec.uint(
-            'view-height', 'view-height', 'view-height',
+            'view-height', null, null,
             GObject.ParamFlags.READABLE,
             0, GLib.MAXUINT32, 0),
     };
@@ -71,12 +78,38 @@ class MainWindow extends Adw.ApplicationWindow {
 
         this._userListPopover.set_parent(this._showUserListButton);
 
+        this._roomList.connect('filter-changed', () => {
+            this._searchView.rooms = this._roomList.searchRooms;
+        });
+
+        this._searchEntry.connect('search-changed', () => {
+            const searchTerms = this._searchEntry.get_text();
+            if (searchTerms) {
+                this._searchTitle.set_text(vprintf(_('Search for “%s”'), searchTerms));
+                this._roomList.search(searchTerms);
+                this._searchView.search = searchTerms;
+                this._viewStack.set_visible_child_name('search');
+            } else {
+                this._viewStack.set_visible_child_name('conversation');
+                this._roomList.setSearchMode(false);
+                this._searchView.cancel();
+            }
+        });
+
         const app = this.application;
         if (app.isTestInstance)
             this.add_css_class('test-instance');
         if (GLib.get_application_name().toLowerCase().includes('snapshot'))
             this.add_css_class('snapshot');
 
+        const actions = [{
+            name: 'search',
+            handler: () => this._searchButton.activate(),
+        }];
+        actions.forEach(a => {
+            app.lookup_action(a.name).connect('activate', a.handler);
+        });
+
         this._roomStack.connect('notify::view-height',
             () => this.notify('view-height'));
 
@@ -131,12 +164,10 @@ class MainWindow extends Adw.ApplicationWindow {
         return this._subtitle ?? '';
     }
 
-    // eslint-disable-next-line camelcase
     get subtitle_visible() {
         return this.subtitle.length > 0;
     }
 
-    // eslint-disable-next-line camelcase
     get view_height() {
         return this._roomStack.view_height;
     }
@@ -149,7 +180,7 @@ class MainWindow extends Adw.ApplicationWindow {
     }
 
     _onAccountsReachableChanged() {
-        let accounts = this._accountsMonitor.visibleAccounts;
+        const accounts = this._accountsMonitor.visibleAccounts;
         this._offlineBanner.revealed =
             accounts.length > 0 && !accounts.some(a => a.reachable);
     }
@@ -179,7 +210,7 @@ class MainWindow extends Adw.ApplicationWindow {
     }
 
     _onAccountsChanged() {
-        let hasAccounts = this._accountsMonitor.visibleAccounts.length > 0;
+        const hasAccounts = this._accountsMonitor.visibleAccounts.length > 0;
         this._roomListRevealer.reveal_child = hasAccounts;
     }
 
@@ -187,12 +218,10 @@ class MainWindow extends Adw.ApplicationWindow {
         return layoutStr.split(',').filter(s => s !== 'menu').join(',');
     }
 
-    // eslint-disable-next-line camelcase
     get active_room() {
         return this._room;
     }
 
-    // eslint-disable-next-line camelcase
     set active_room(room) {
         if (room === this._room)
             return;
@@ -240,16 +269,16 @@ class MainWindow extends Adw.ApplicationWindow {
         if (this.active_room)
             return;
 
-        let selectedRoom = this._settings.get_value('last-selected-channel').deep_unpack();
-        for (let prop in selectedRoom)
+        const selectedRoom = this._settings.get_value('last-selected-channel').deep_unpack();
+        for (const prop in selectedRoom)
             selectedRoom[prop] = selectedRoom[prop].deep_unpack();
 
         if (!selectedRoom.account)
             return;
 
         let roomId = null;
-        let account = this._accountsMonitor.lookupAccount(selectedRoom.account);
-        let channelName = selectedRoom.channel;
+        const account = this._accountsMonitor.lookupAccount(selectedRoom.account);
+        const channelName = selectedRoom.channel;
         if (account && account.visible && channelName)
             roomId = Polari.create_room_id(account, channelName, Tp.HandleType.ROOM);
 
@@ -281,7 +310,7 @@ class MainWindow extends Adw.ApplicationWindow {
             this._room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP))
             numMembers = this._room.channel.group_dup_members_contacts().length;
 
-        let accessibleName = vprintf(ngettext(
+        const accessibleName = vprintf(ngettext(
             '%d user',
             '%d users', numMembers), numMembers);
         this._showUserListButton.update_property(
@@ -292,13 +321,13 @@ class MainWindow extends Adw.ApplicationWindow {
     _updateTitlebar() {
         let subtitle = '';
         if (this._room && this._room.topic) {
-            let urls = Utils.findUrls(this._room.topic);
+            const urls = Utils.findUrls(this._room.topic);
             let pos = 0;
             for (let i = 0; i < urls.length; i++) {
-                let url = urls[i];
-                let text = GLib.markup_escape_text(
+                const url = urls[i];
+                const text = GLib.markup_escape_text(
                     this._room.topic.substr(pos, url.pos - pos), -1);
-                let urlText = GLib.markup_escape_text(url.url, -1);
+                const urlText = GLib.markup_escape_text(url.url, -1);
                 subtitle += `${text} <a href="${urlText}">${urlText}<${'/'}a>`;
                 pos = url.pos + url.url.length;
             }
@@ -318,4 +347,12 @@ class MainWindow extends Adw.ApplicationWindow {
         this._importProgress.set_fraction(n / max);
         this._importProgress.visible = max !== n;
     }
+
+    showSearchInline(room, date) {
+        this._searchButton.set_active(false);
+        this.active_room = room;
+        this._viewStack.set_visible_child_name('conversation');
+        const view = this._roomStack.get_child_by_name(room.id);
+        view.showSearchInline(date);
+    }
 });
