@@ -21,7 +21,7 @@ export default GObject.registerClass(
 class RoomStack extends Gtk.Stack {
     static [GObject.properties] = {
         'view-height': GObject.ParamSpec.uint(
-            'view-height', 'view-height', 'view-height',
+            'view-height', null, null,
             GObject.ParamFlags.READABLE,
             0, GLib.MAXUINT32, 0),
     };
@@ -88,7 +88,6 @@ class RoomStack extends Gtk.Stack {
         }
     }
 
-    // eslint-disable-next-line camelcase
     get view_height() {
         return this._viewHeight;
     }
@@ -119,7 +118,7 @@ class RoomStack extends Gtk.Stack {
         const room = this.get_root().active_room;
         if (!room)
             return;
-        let sensitive = room && room.channel;
+        const sensitive = room && room.channel;
         this._rooms.get(room.id).inputSensitive = sensitive;
     }
 });
@@ -128,24 +127,24 @@ export const MessageInfoBar = GObject.registerClass(
 class MessageInfoBar extends Gtk.InfoBar {
     static [GObject.properties] = {
         'title': GObject.ParamSpec.string(
-            'title', 'title', 'title',
+            'title', null, null,
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             ''),
         'subtitle': GObject.ParamSpec.string(
-            'subtitle', 'subtitle', 'subtitle',
+            'subtitle', null, null,
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             ''),
     };
 
     constructor(params) {
-        let defaultParams = {
+        const defaultParams = {
             show_close_button: true,
             revealed: false,
             valign: Gtk.Align.START,
         };
         super(Object.assign(defaultParams, params));
 
-        let box = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
+        const box = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
         this.add_child(box);
 
         this._titleLabel = new Gtk.Label({
@@ -177,8 +176,8 @@ class MessageInfoBar extends Gtk.InfoBar {
 const SavePasswordConfirmationBar = GObject.registerClass(
 class SavePasswordConfirmationBar extends MessageInfoBar {
     constructor(room) {
-        let title = _('Should the password be saved?');
-        let subtitle = vprintf(
+        const title = _('Should the password be saved?');
+        const subtitle = vprintf(
             _('Identification will happen automatically the next time you connect to %s'),
             room.account.display_name);
         super({title, subtitle});
@@ -201,8 +200,8 @@ class SavePasswordConfirmationBar extends MessageInfoBar {
         if (response === Gtk.ResponseType.ACCEPT)
             return;
 
-        let app = Gio.Application.get_default();
-        let target = new GLib.Variant('o', this._room.account.object_path);
+        const app = Gio.Application.get_default();
+        const target = new GLib.Variant('o', this._room.account.object_path);
         app.lookup_action('discard-identify-password').activate(target);
     }
 
@@ -302,7 +301,16 @@ class RoomView extends Gtk.Overlay {
         this.add_overlay(new ChannelErrorBar(room));
 
         this._view = new ChatView(room);
-        toolbarView.content = this._view;
+
+        const loadingStatus = new Adw.StatusPage();
+        loadingStatus.paintable = new Adw.SpinnerPaintable({
+            widget: loadingStatus,
+        });
+        toolbarView.content = loadingStatus;
+
+        this._view.connect('logs-ready', () => {
+            toolbarView.content = this._view;
+        });
 
         this._entryArea = new EntryArea({
             room,
@@ -337,4 +345,8 @@ class RoomView extends Gtk.Overlay {
     set inputSensitive(sensitive) {
         this._entryArea.sensitive = sensitive;
     }
+
+    showSearchInline(date) {
+        this._view.showSearchInline(date);
+    }
 });
