@@ -57,6 +57,7 @@ class UserListPopover extends Gtk.Popover {
 
         this._entry = new Gtk.SearchEntry();
         this._entry.connect('search-changed', this._updateFilter.bind(this));
+        this._entry.connect('stop-search', this._onStopSearch.bind(this));
         this._revealer.set_child(this._entry);
     }
 
@@ -78,7 +79,7 @@ class UserListPopover extends Gtk.Popover {
         const viewHeight = this.get_root().view_height;
         const [popoverHeight] = this.measure(Gtk.Orientation.VERTICAL, -1);
         const [userListHeight] = this._userList.measure(Gtk.Orientation.VERTICAL, -1);
-        let chromeHeight = popoverHeight - userListHeight;
+        const chromeHeight = popoverHeight - userListHeight;
         this._userList.max_content_height = viewHeight - chromeHeight;
     }
 
@@ -103,7 +104,7 @@ class UserListPopover extends Gtk.Popover {
         if (!this._userList)
             return;
 
-        let reveal = this._entry.text !== '' ||
+        const reveal = this._entry.text !== '' ||
                      this._userList.numRows > FILTER_ENTRY_THRESHOLD;
         this._revealer.reveal_child = reveal;
     }
@@ -113,6 +114,13 @@ class UserListPopover extends Gtk.Popover {
             return;
         this._userList.setFilter(this._entry.text);
     }
+
+    _onStopSearch() {
+        if (this._entry.text.length > 0)
+            this._entry.text = '';
+        else
+            this.popdown();
+    }
 });
 
 export const UserDetails = GObject.registerClass(
@@ -120,7 +128,6 @@ class UserDetails extends Gtk.Box {
     static [Gtk.template] = 'resource:///org/gnome/Polari/ui/user-details.ui';
     static [Gtk.internalChildren] = [
         'spinnerBox',
-        'spinner',
         'detailsGrid',
         'fullnameLabel',
         'lastLabel',
@@ -130,11 +137,11 @@ class UserDetails extends Gtk.Box {
 
     static [GObject.properties] = {
         'expanded': GObject.ParamSpec.boolean(
-            'expanded', 'expanded', 'expanded',
+            'expanded', null, null,
             GObject.ParamFlags.READWRITE,
             false),
         'notifications-enabled': GObject.ParamSpec.boolean(
-            'notifications-enabled', 'notifications-enabled', 'notifications-enabled',
+            'notifications-enabled', null, null,
             GObject.ParamFlags.READWRITE,
             false),
     };
@@ -143,7 +150,7 @@ class UserDetails extends Gtk.Box {
     _user = null;
 
     constructor(params = {}) {
-        let {user} = params;
+        const {user} = params;
         delete params.user;
 
         super(params);
@@ -207,7 +214,6 @@ class UserDetails extends Gtk.Box {
     _expand() {
         this._detailsGrid.visible = this._initialDetailsLoaded;
         this._spinnerBox.visible = !this._initialDetailsLoaded;
-        this._spinner.start();
 
         this._cancellable = new Gio.Cancellable();
 
@@ -222,8 +228,6 @@ class UserDetails extends Gtk.Box {
     }
 
     _unexpand() {
-        this._spinner.stop();
-
         if (this._cancellable)
             this._cancellable.cancel();
         this._cancellable = null;
@@ -233,7 +237,7 @@ class UserDetails extends Gtk.Box {
         this._initialDetailsLoaded = true;
 
         let fn, last;
-        let info = this._user.get_contact_info();
+        const info = this._user.get_contact_info();
         for (let i = 0; i < info.length; i++) {
             if (info[i].field_name === 'fn')
                 [fn] = info[i].field_value;
@@ -257,16 +261,15 @@ class UserDetails extends Gtk.Box {
     }
 
     _revealDetails() {
-        this._spinner.stop();
         this._spinnerBox.hide();
         this._detailsGrid.show();
     }
 
     _onMessageButtonClicked() {
-        let account = this._user.connection.get_account();
+        const account = this._user.connection.get_account();
 
-        let app = Gio.Application.get_default();
-        let action = app.lookup_action('message-user');
+        const app = Gio.Application.get_default();
+        const action = app.lookup_action('message-user');
         action.activate(GLib.Variant.new('(sssb)', [
             account.get_object_path(),
             this._user.alias,
@@ -337,7 +340,7 @@ class UserPopover extends Gtk.Popover {
         this._nickLabel.label = this._nickname;
         this._userDetails.nickname = nickname;
 
-        let actionName = this._userTracker.getNotifyActionName(this._nickname);
+        const actionName = this._userTracker.getNotifyActionName(this._nickname);
         this._notifyButton.action_name = actionName;
 
         this._setBasenick(Polari.util_get_basenick(nickname));
@@ -378,8 +381,8 @@ class UserPopover extends Gtk.Popover {
     }
 
     _onStatusChanged() {
-        let status = this._userTracker.getNickStatus(this._nickname);
-        let roomStatus = this._userTracker.getNickRoomStatus(
+        const status = this._userTracker.getNickStatus(this._nickname);
+        const roomStatus = this._userTracker.getNickRoomStatus(
             this._nickname, this._room);
 
         let label;
@@ -407,6 +410,13 @@ class UserPopover extends Gtk.Popover {
 
 const UserListRow = GObject.registerClass(
 class UserListRow extends Gtk.ListBoxRow {
+    static [GObject.properties] = {
+        'filter': GObject.ParamSpec.string(
+            'filter', 'filter', 'filter',
+            GObject.ParamFlags.READWRITE,
+            ''),
+    };
+
     constructor(user) {
         super({name: `UserListRow ${user.alias}`});
 
@@ -422,6 +432,8 @@ class UserListRow extends Gtk.ListBoxRow {
 
         this._revealer.connect('notify::reveal-child',
             this._onExpandedChanged.bind(this));
+
+        this.connect('notify::filter', () => this._updateLabel());
     }
 
     get user() {
@@ -439,10 +451,10 @@ class UserListRow extends Gtk.ListBoxRow {
     }
 
     _createWidget() {
-        let vbox = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
+        const vbox = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
         this.set_child(vbox);
 
-        let hbox = new Gtk.Box({
+        const hbox = new Gtk.Box({
             margin_end: 12,
             margin_start: 4,
             margin_top: 4,
@@ -473,7 +485,7 @@ class UserListRow extends Gtk.ListBoxRow {
         if (this._revealer.get_child())
             return;
 
-        let details = new UserDetails({user: this._user});
+        const details = new UserDetails({user: this._user});
 
         this._revealer.bind_property('reveal-child', details, 'expanded', 0);
 
@@ -481,34 +493,17 @@ class UserListRow extends Gtk.ListBoxRow {
     }
 
     shouldShow() {
-        return this._user.alias.toLowerCase().includes(this._filter);
-    }
-
-    setFilter(filter) {
-        this._filter = filter.toLowerCase();
-        this._updateLabel();
+        return this._user.alias.toLowerCase().includes(this.filter.toLowerCase());
     }
 
     _updateLabel() {
-        let filterIndex = -1;
-        if (this._filter)
-            filterIndex = this._user.alias.toLowerCase().indexOf(this._filter);
-
-        if (filterIndex < 0) {
-            this._label.label = this._user.alias;
-        } else {
-            let preMatch = this._user.alias.substring(0, filterIndex);
-            let theMatch = this._user.alias.substring(
-                filterIndex,
-                filterIndex + this._filter.length);
-            let postMatch = this._user.alias.substring(
-                filterIndex + this._filter.length);
-            this._label.label = `${preMatch}<b>${theMatch}<${'/'}b>${postMatch}`;
-        }
+        const str = GLib.regex_escape_string(this.filter ?? '', -1);
+        const regex = new RegExp(`(${str})`, 'i');
+        this._label.label = this._user.alias.replace(regex, '<b>$1</b>');
     }
 
     _updateArrowVisibility() {
-        let flags = this.get_state_flags();
+        const flags = this.get_state_flags();
         this._arrow.visible = this.expand ||
                               flags & Gtk.StateFlags.PRELIGHT ||
                               flags & Gtk.StateFlags.FOCUSED;
@@ -528,40 +523,15 @@ class UserListRow extends Gtk.ListBoxRow {
 
 const UserList = GObject.registerClass(
 class UserList extends Gtk.ScrolledWindow {
-    _init(room) {
-        super._init({
-            hexpand: true,
-            has_frame: true,
-            hscrollbar_policy: Gtk.PolicyType.NEVER,
-            propagate_natural_height: true,
-            propagate_natural_width: true,
-        });
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/user-list.ui';
+    static [Gtk.internalChildren] = [
+        'list',
+        'stack',
+    ];
 
-        this._list = new Gtk.ListBox({vexpand: true});
-        this.set_child(this._list);
-        let placeholder = new Gtk.Box({
-            halign: Gtk.Align.CENTER,
-            valign: Gtk.Align.CENTER,
-            orientation: Gtk.Orientation.VERTICAL,
-            margin_top: 32,
-            margin_bottom: 32,
-            margin_start: 32,
-            margin_end: 32,
-            spacing: 6,
-        });
-        placeholder.append(new Gtk.Image({
-            icon_name: 'edit-find-symbolic',
-            pixel_size: 64,
-        }));
-        placeholder.append(new Gtk.Label({
-            label: _('No Results'),
-        }));
+    constructor(room) {
+        super();
 
-        placeholder.add_css_class('placeholder');
-
-        this._list.set_placeholder(placeholder);
-
-        this._list.set_selection_mode(Gtk.SelectionMode.NONE);
         this._filter = '';
         this._list.set_filter_func(this._filterRows.bind(this));
         this._list.set_sort_func(this._sort.bind(this));
@@ -573,7 +543,7 @@ class UserList extends Gtk.ScrolledWindow {
         this._rows = new Map();
         this._activeRow = null;
 
-        let roomSignals = [{
+        const roomSignals = [{
             name: 'member-renamed',
             handler: this._onMemberRenamed.bind(this),
         }, {
@@ -614,6 +584,7 @@ class UserList extends Gtk.ScrolledWindow {
     setFilter(filter) {
         this._filter = filter;
         this._list.invalidate_filter();
+        this._syncVisiblePage();
     }
 
     _onMemberRenamed(room, oldMember, newMember) {
@@ -639,19 +610,19 @@ class UserList extends Gtk.ScrolledWindow {
         if (!room.channel)
             return;
 
-        let members = room.channel.group_dup_members_contacts();
+        const members = room.channel.group_dup_members_contacts();
         for (let i = 0; i < members.length; i++)
             this._addMember(members[i]);
     }
 
     _addMember(member) {
-        let row = new UserListRow(member);
+        const row = new UserListRow(member);
         this._rows.set(member, row);
         this._list.append(row);
     }
 
     _removeMember(member) {
-        let row = this._rows.get(member);
+        const row = this._rows.get(member);
         if (row)
             this._list.remove(row);
         row?.run_dispose();
@@ -674,7 +645,14 @@ class UserList extends Gtk.ScrolledWindow {
     }
 
     _filterRows(row) {
-        row.setFilter(this._filter);
+        row.filter = this._filter;
         return row.shouldShow();
     }
+
+    _syncVisiblePage() {
+        const hasVisibleRows = [...this._list].some(c => c.get_child_visible());
+        this._stack.visible_child_name = hasVisibleRows
+            ? 'list'
+            : 'placeholder';
+    }
 });
